@@ -46,7 +46,7 @@ class authenticate:
                     userkeys.append(val2)
             else:
                 print("LYK_ADMIN table is empty")
-            print(userkeys)
+            # print(userkeys)
             if userkey in userkeys:
                 lc = 10
                 nc = 10
